Registry for Frictionless Energy data (Friendly data)
=====================================================

This is the schema registry for the Frictionless Energy data
implementation developed by the SENTINEL collaboration.
